@@ -14,28 +14,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-#' Summarise cohort overlap
+#' Summarise overlap between cohorts in a cohort table
 #'
-#' @param cohort  A cohort table in a cdm reference.
-#' @param cohortId  Vector of cohort definition ids to include, if NULL, all
-#' cohort definition ids will be used.
-#' @param strata List of the stratifications within each group to be considered.
-#' Must be column names in the cohort table provided.
+#' @param cohort A cohort table in the cdm.
+#' @param cohortId A cohort definition id to restrict by. If NULL, all cohorts
+#' will be included.
+#' @param strata A list of variables to stratify results. These variables
+#' must have been added as additional columns in the cohort table.
+#'
+#' @return  A summary of overlap between cohorts in the cohort table.
 #'
-#' @return A summarised result.
 #' @export
 #'
 #' @examples
 #' \donttest{
 #' library(CohortCharacteristics)
 #' cdm <- CohortCharacteristics::mockCohortCharacteristics()
-#' results <- summariseCohortOverlap(cdm$cohort2)
+#' summariseCohortOverlap(cdm$cohort2) |> dplyr::glimpse()
 #' CDMConnector::cdmDisconnect(cdm = cdm)
 #' }
 summariseCohortOverlap <- function(cohort,
                                    cohortId = NULL,
                                    strata = list()) {
-
   # validate inputs
   assertClass(cohort, "cohort_table")
   checkmate::assertTRUE(all(c("cohort_definition_id", "subject_id", "cohort_start_date", "cohort_end_date") %in% colnames(cohort)))
@@ -58,7 +58,7 @@ summariseCohortOverlap <- function(cohort,
     cohortId <- ids
   } else {
     indNot <- which(!cohortId %in% ids)
-    if (length(indNot)>0) {
+    if (length(indNot) > 0) {
       cli::cli_warn("{cohortId[indNot]} {?is/are} not in the cohort table.")
     }
   }
@@ -75,26 +75,31 @@ summariseCohortOverlap <- function(cohort,
       cdm[[name]] |>
         dplyr::distinct(.data$subject_id, .data$cohort_name) |>
         dplyr::rename("cohort_name_comparator" = "cohort_name") |>
-        dplyr::select(dplyr::all_of(c("subject_id","cohort_name_comparator"))),
-      by = "subject_id") |>
+        dplyr::select(dplyr::all_of(c("subject_id", "cohort_name_comparator"))),
+      by = "subject_id"
+    ) |>
     dplyr::compute()
 
   # overall
   cohort_counts <- omopgenerics::cohortCount(cdm[[name]]) |>
     dplyr::inner_join(omopgenerics::settings(cdm[[name]]),
-                      by = "cohort_definition_id") |>
+      by = "cohort_definition_id"
+    ) |>
     dplyr::select("cohort_name", "number_subjects")
   # get inner join counts
   overlap <- overlapOverallData |>
-    dplyr::group_by(.data$cohort_name_reference,
-                    .data$cohort_name_comparator) |>
+    dplyr::group_by(
+      .data$cohort_name_reference,
+      .data$cohort_name_comparator
+    ) |>
     dplyr::summarise(
       "number_subjects_overlap" = dplyr::n(),
-      .groups = "drop") |>
+      .groups = "drop"
+    ) |>
     dplyr::collect() |>
     dplyr::filter(.data$cohort_name_reference != .data$cohort_name_comparator) |>
-    dplyr::left_join(cohort_counts |> dplyr::rename_with(~paste0(.x, "_reference")), by = "cohort_name_reference") |>
-    dplyr::left_join(cohort_counts |> dplyr::rename_with(~paste0(.x, "_comparator")), by = "cohort_name_comparator")
+    dplyr::left_join(cohort_counts |> dplyr::rename_with(~ paste0(.x, "_reference")), by = "cohort_name_reference") |>
+    dplyr::left_join(cohort_counts |> dplyr::rename_with(~ paste0(.x, "_comparator")), by = "cohort_name_comparator")
 
   # overlap counts and percentages
   overlap <- overlap |>
@@ -112,53 +117,59 @@ summariseCohortOverlap <- function(cohort,
         cdm[[name]] |>
           dplyr::distinct(dplyr::across(dplyr::all_of(c("subject_id", "cohort_name", unique(unlist(strata)))))) |>
           dplyr::rename("cohort_name_comparator" = "cohort_name") |>
-          dplyr::select(dplyr::all_of(c("subject_id","cohort_name_comparator", unique(unlist(strata))))),
-        by = c("subject_id", unique(unlist(strata)))) |>
+          dplyr::select(dplyr::all_of(c("subject_id", "cohort_name_comparator", unique(unlist(strata))))),
+        by = c("subject_id", unique(unlist(strata)))
+      ) |>
       dplyr::compute()
 
     overlap <- overlap |>
       dplyr::union_all(
-        lapply(strata,
-               function(strataName, data = overlapStrataData) {
-                 overlap.strata <- data |>
-                   dplyr::group_by(dplyr::across(dplyr::all_of(
-                     c("cohort_name_reference", "cohort_name_comparator", strataName)))
-                   ) |>
-                   dplyr::summarise(
-                     "number_subjects" = dplyr::n(),
-                     .groups = "drop") |>
-                   dplyr::collect()
-                 cohort_counts.strata <- overlap.strata |>
-                   dplyr::filter(.data$cohort_name_reference == .data$cohort_name_comparator) |>
-                   dplyr::rename("cohort_name" = "cohort_name_reference") |>
-                   dplyr::select(!"cohort_name_comparator")
-                 overlap.strata <- overlap.strata |>
-                   dplyr::filter(.data$cohort_name_reference != .data$cohort_name_comparator) |>
-                   dplyr::rename_with(.fn = ~paste0(.x, "_overlap"), .cols = dplyr::starts_with("number")) |>
-                   dplyr::left_join(
-                     cohort_counts.strata |>
-                       dplyr::rename_with(
-                         .fn = ~paste0(.x, "_reference"),
-                         .cols = dplyr::all_of(c("cohort_name", "number_subjects"))
-                       ),
-                     by = c("cohort_name_reference", strataName)
-                   ) |>
-                   dplyr::left_join(
-                     cohort_counts.strata |>
-                       dplyr::rename_with(
-                         .fn = ~paste0(.x, "_comparator"),
-                         .cols = dplyr::all_of(c("cohort_name", "number_subjects"))
-                       ),
-                     by = c("cohort_name_comparator", strataName)
-                   )
-                 overlap.strata <- overlap.strata |>
-                   getOverlapEstimates() |>
-                   visOmopResults::uniteGroup(cols = c("cohort_name_reference", "cohort_name_comparator")) |>
-                   visOmopResults::uniteStrata(cols = strataName) |>
-                   dplyr::select(dplyr::all_of(c("group_name", "group_level", "strata_name", "strata_level", "variable_name",
-                                                 "variable_level", "estimate_name", "estimate_type", "estimate_value")))
-                 return(overlap.strata)
-               }) |>
+        lapply(
+          strata,
+          function(strataName, data = overlapStrataData) {
+            overlap.strata <- data |>
+              dplyr::group_by(dplyr::across(dplyr::all_of(
+                c("cohort_name_reference", "cohort_name_comparator", strataName)
+              ))) |>
+              dplyr::summarise(
+                "number_subjects" = dplyr::n(),
+                .groups = "drop"
+              ) |>
+              dplyr::collect()
+            cohort_counts.strata <- overlap.strata |>
+              dplyr::filter(.data$cohort_name_reference == .data$cohort_name_comparator) |>
+              dplyr::rename("cohort_name" = "cohort_name_reference") |>
+              dplyr::select(!"cohort_name_comparator")
+            overlap.strata <- overlap.strata |>
+              dplyr::filter(.data$cohort_name_reference != .data$cohort_name_comparator) |>
+              dplyr::rename_with(.fn = ~ paste0(.x, "_overlap"), .cols = dplyr::starts_with("number")) |>
+              dplyr::left_join(
+                cohort_counts.strata |>
+                  dplyr::rename_with(
+                    .fn = ~ paste0(.x, "_reference"),
+                    .cols = dplyr::all_of(c("cohort_name", "number_subjects"))
+                  ),
+                by = c("cohort_name_reference", strataName)
+              ) |>
+              dplyr::left_join(
+                cohort_counts.strata |>
+                  dplyr::rename_with(
+                    .fn = ~ paste0(.x, "_comparator"),
+                    .cols = dplyr::all_of(c("cohort_name", "number_subjects"))
+                  ),
+                by = c("cohort_name_comparator", strataName)
+              )
+            overlap.strata <- overlap.strata |>
+              getOverlapEstimates() |>
+              visOmopResults::uniteGroup(cols = c("cohort_name_reference", "cohort_name_comparator")) |>
+              visOmopResults::uniteStrata(cols = strataName) |>
+              dplyr::select(dplyr::all_of(c(
+                "group_name", "group_level", "strata_name", "strata_level", "variable_name",
+                "variable_level", "estimate_name", "estimate_type", "estimate_value"
+              )))
+            return(overlap.strata)
+          }
+        ) |>
           dplyr::bind_rows()
       )
   }
@@ -168,18 +179,34 @@ summariseCohortOverlap <- function(cohort,
     omopgenerics::settings() |>
     dplyr::filter(.data$cohort_definition_id %in% .env$cohortId) |>
     dplyr::pull(.data$cohort_name)
-  cohortCombinations <- tidyr::expand_grid(
+  combinations <- tidyr::expand_grid(
     cohort_name_reference = names,
     cohort_name_comparator = names
   ) |>
     dplyr::filter(.data$cohort_name_reference != .data$cohort_name_comparator) |>
-    visOmopResults::uniteGroup(cols = c("cohort_name_reference", "cohort_name_comparator"))
+    visOmopResults::uniteGroup(cols = c("cohort_name_reference", "cohort_name_comparator")) |>
+    dplyr::mutate(strata_name = "overall", strata_level = "overall")
 
-  noOverlap <- cohortCombinations |>
+  if (length(strata) > 0) {
+    combinations <- lapply(strata, function(strataCols, data = overlapStrataData) {
+      data |>
+        dplyr::select(dplyr::all_of(strataCols)) |>
+        dplyr::distinct() |>
+        dplyr::collect() |>
+        visOmopResults::uniteStrata(cols = strataCols)
+    }) |>
+      dplyr::bind_rows() |>
+      dplyr::cross_join(
+        combinations |> dplyr::select(-"strata_name", -"strata_level")
+      ) |>
+      dplyr::bind_rows(combinations)
+  }
+
+  noOverlap <- combinations |>
     dplyr::anti_join(
       overlap |>
-        dplyr::distinct(.data$group_name, .data$group_level),
-      by = c("group_name", "group_level")
+        dplyr::distinct(.data$group_name, .data$group_level, .data$strata_name, .data$strata_level),
+      by = c("group_name", "group_level", "strata_name", "strata_level")
     )
 
   if (nrow(noOverlap) > 0) {
@@ -187,14 +214,11 @@ summariseCohortOverlap <- function(cohort,
       dplyr::union(
         noOverlap |>
           dplyr::cross_join(
-            overlap |>
-              dplyr::distinct(.data$strata_name, .data$strata_level)
-          ) |>
-          dplyr::cross_join(
-            tidyr::expand_grid(variable_name = "number_subjects",
-                               variable_level = c("reference", "comparator", "overlap"),
-                               estimate_name = c("count", "percentage"),
-                               estimate_value = "0"
+            tidyr::expand_grid(
+              variable_name = c("reference", "comparator", "overlap"),
+              variable_level = "number_subjects",
+              estimate_name = c("count", "percentage"),
+              estimate_value = "0"
             ) |>
               dplyr::mutate(estimate_type = dplyr::if_else(.data$estimate_name == "count", "integer", "percentage"))
           )
@@ -205,18 +229,21 @@ summariseCohortOverlap <- function(cohort,
     dplyr::mutate(
       result_id = as.integer(1),
       cdm_name = CDMConnector::cdmName(cdm),
-      result_type = "cohort_overlap",
-      package_name = "CohortCharacteristics",
-      package_version = as.character(utils::packageVersion("CohortCharacteristics")),
-      additional_name ="overall",
+      additional_name = "overall",
       additional_level = "overall",
       variable_level = dplyr::if_else(
         .data$variable_level == "reference" | .data$variable_level == "comparator",
         paste0("only_in_", .data$variable_level), .data$variable_level
       )
     ) |>
-    dplyr::select(dplyr::all_of(omopgenerics::resultColumns("summarised_result"))) |>
-    omopgenerics::newSummarisedResult()
+    omopgenerics::newSummarisedResult(
+      settings = dplyr::tibble(
+        result_id = 1L,
+        result_type = "cohort_overlap",
+        package_name = "CohortCharacteristics",
+        package_version = as.character(utils::packageVersion("CohortCharacteristics"))
+      )
+    )
 
   return(overlap)
 }
@@ -230,8 +257,8 @@ getOverlapEstimates <- function(x) {
     ) |>
     tidyr::pivot_longer(cols = dplyr::starts_with("number"), names_to = "variable_name", values_to = "estimate_value") |>
     dplyr::mutate(
-      variable_level = gsub("number_subjects_", "", .data$variable_name),
-      variable_name = gsub("_overlap|_reference|_comparator", "", .data$variable_name),
+      variable_level = gsub("_overlap|_reference|_comparator", "", .data$variable_name),
+      variable_name = gsub("number_subjects_", "", .data$variable_name),
       estimate_name = "count",
       estimate_type = "integer",
       estimate_value = as.character(.data$estimate_value)
@@ -239,16 +266,16 @@ getOverlapEstimates <- function(x) {
     dplyr::union_all(
       x |>
         dplyr::mutate(
-          total_subjects = .data$number_subjects_comparator + .data$number_subjects_reference -.data$number_subjects_overlap,
-          number_subjects_reference = (.data$number_subjects_reference - .data$number_subjects_overlap)/(.data$total_subjects) * 100,
-          number_subjects_comparator = (.data$number_subjects_comparator - .data$number_subjects_overlap)/(.data$total_subjects) * 100,
-          number_subjects_overlap = .data$number_subjects_overlap/(.data$total_subjects) * 100
+          total_subjects = .data$number_subjects_comparator + .data$number_subjects_reference - .data$number_subjects_overlap,
+          number_subjects_reference = (.data$number_subjects_reference - .data$number_subjects_overlap) / (.data$total_subjects) * 100,
+          number_subjects_comparator = (.data$number_subjects_comparator - .data$number_subjects_overlap) / (.data$total_subjects) * 100,
+          number_subjects_overlap = .data$number_subjects_overlap / (.data$total_subjects) * 100
         ) |>
         dplyr::select(!dplyr::all_of(c("total_subjects"))) |>
         tidyr::pivot_longer(cols = dplyr::starts_with("number"), names_to = "variable_name", values_to = "estimate_value") |>
         dplyr::mutate(
-          variable_level = gsub("number_subjects_", "", .data$variable_name),
-          variable_name = gsub("_overlap|_reference|_comparator", "", .data$variable_name),
+          variable_level = gsub("_overlap|_reference|_comparator", "", .data$variable_name),
+          variable_name = gsub("number_subjects_", "", .data$variable_name),
           estimate_name = "percentage",
           estimate_type = "percentage",
           estimate_value = as.character(.data$estimate_value)
